==> lpc55-pac-0.4.0.crate: lpc55-pac-0.4.0/src/syscon/key_block.rs <==
#[doc = "Register `KEY_BLOCK` writer"]
pub struct W(crate::W<KEY_BLOCK_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<KEY_BLOCK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<KEY_BLOCK_SPEC>> for W {
    fn from(writer: crate::W<KEY_BLOCK_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `KEY_BLOCK` writer - Write a value to block quiddikey/PUF all index."]
pub struct KEY_BLOCK_W<'a> {
    w: &'a mut W,
}
impl<'a> KEY_BLOCK_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl W {
    #[doc = "Bits 0:31 - Write a value to block quiddikey/PUF all index."]
    #[inline(always)]
    pub fn key_block(&mut self) -> KEY_BLOCK_W {
        KEY_BLOCK_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "block quiddikey/PUF all index.\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [key_block](index.html) module"]
pub struct KEY_BLOCK_SPEC;
impl crate::RegisterSpec for KEY_BLOCK_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [key_block::W](W) writer structure"]
impl crate::Writable for KEY_BLOCK_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets KEY_BLOCK to value 0x3cc3_5aa5"]
impl crate::Resettable for KEY_BLOCK_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x3cc3_5aa5
    }
}

==> lpc55-pac-0.5.0.crate: lpc55-pac-0.5.0/src/syscon/key_block.rs <==
#[doc = "Register `KEY_BLOCK` writer"]
pub struct W(crate::W<KEY_BLOCK_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<KEY_BLOCK_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<KEY_BLOCK_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<KEY_BLOCK_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `KEY_BLOCK` writer - Write a value to block quiddikey/PUF all index."]
pub struct KEY_BLOCK_W<'a> {
    w: &'a mut W,
}
impl<'a> KEY_BLOCK_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl W {
    #[doc = "Bits 0:31 - Write a value to block quiddikey/PUF all index."]
    #[inline(always)]
    pub fn key_block(&mut self) -> KEY_BLOCK_W {
        KEY_BLOCK_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "block quiddikey/PUF all index.\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [key_block](index.html) module"]
pub struct KEY_BLOCK_SPEC;
impl crate::RegisterSpec for KEY_BLOCK_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [key_block::W](W) writer structure"]
impl crate::Writable for KEY_BLOCK_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets KEY_BLOCK to value 0x3cc3_5aa5"]
impl crate::Resettable for KEY_BLOCK_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x3cc3_5aa5
    }
}
